aboutsummaryrefslogtreecommitdiff
path: root/ci
diff options
context:
space:
mode:
authorMarcoFalke <*~=`'#}+{/-|&$^_@721217.xyz>2023-08-03 14:22:15 +0200
committerMarcoFalke <*~=`'#}+{/-|&$^_@721217.xyz>2023-10-24 18:52:00 +0200
commitfae379b6b1c9d434821acc348f010d67c4fee927 (patch)
treecbac2a5a1a6d608615f15006e29a5109b9a373f2 /ci
parentfab1ef9512c364c2b906ebfacc76439816e216d1 (diff)
downloadbitcoin-fae379b6b1c9d434821acc348f010d67c4fee927.tar.xz
build: Bump minimum supported Clang to clang-13
Diffstat (limited to 'ci')
-rwxr-xr-xci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh b/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh
index 2d181f1bb8..20044d7e1c 100755
--- a/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh
+++ b/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh
@@ -8,8 +8,8 @@ export LC_ALL=C.UTF-8
export CONTAINER_NAME=ci_native_nowallet_libbitcoinkernel
export CI_IMAGE_NAME_TAG="docker.io/debian:bullseye"
-# Use minimum supported python3.9 and clang-10 (or best-effort clang-11), see doc/dependencies.md
-export PACKAGES="python3-zmq clang-11 llvm-11 libc++abi-11-dev libc++-11-dev"
-export DEP_OPTS="NO_WALLET=1 CC=clang-11 CXX='clang++-11 -stdlib=libc++'"
+# Use minimum supported python3.9 and clang-13, see doc/dependencies.md
+export PACKAGES="python3-zmq clang-13 llvm-13 libc++abi-13-dev libc++-13-dev"
+export DEP_OPTS="NO_WALLET=1 CC=clang-13 CXX='clang++-13 -stdlib=libc++'"
export GOAL="install"
export BITCOIN_CONFIG="--enable-reduce-exports --enable-experimental-util-chainstate --with-experimental-kernel-lib --enable-shared"